core

package
v0.0.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 12, 2020 License: Apache-2.0, BSD-2-Clause, BSD-3-Clause, + 2 more Imports: 4 Imported by: 0

Documentation

Overview

Package core implements some core functions used by apimachinery.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func WriteResponse

func WriteResponse(c *gin.Context, err error, data interface{})

WriteResponse write an error or the response data into http response body. It use errors.ParseCoder to parse any error into errors.Coder errors.Coder contains error code, user-safe error message and http status code.

Types

type ErrResponse

type ErrResponse struct {
	Code      int    `json:"code"`
	Message   string `json:"message"`
	Reference string `json:"reference,omitempty"`
}

ErrResponse defines the return messages when an error occurred. reference will be omitted if it does not exist.

Jump to